Class: Google::Apis::DatastoreV1::AllocateIdsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

The request for Datastore.AllocateIds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocateIdsRequest

Returns a new instance of AllocateIdsRequest.



194
195
196
# File 'lib/google/apis/datastore_v1/classes.rb', line 194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

The ID of the database against which to make the request. '(default)' is not allowed; please use empty string '' to refer the default database. Corresponds to the JSON property databaseId

Returns:

  • (String)


181
182
183
# File 'lib/google/apis/datastore_v1/classes.rb', line 181

def database_id
  @database_id
end

#keysArray<Google::Apis::DatastoreV1::Key>

Required. A list of keys with incomplete key paths for which to allocate IDs. No key may be reserved/read-only. Corresponds to the JSON property keys

Returns:



187
188
189
# File 'lib/google/apis/datastore_v1/classes.rb', line 187

def keys
  @keys
end

#request_optionsGoogle::Apis::DatastoreV1::RequestOptions

Options for a request. Corresponds to the JSON property requestOptions



192
193
194
# File 'lib/google/apis/datastore_v1/classes.rb', line 192

def request_options
  @request_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



199
200
201
202
203
# File 'lib/google/apis/datastore_v1/classes.rb', line 199

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @keys = args[:keys] if args.key?(:keys)
  @request_options = args[:request_options] if args.key?(:request_options)
end