Class: Google::Apis::DatastoreV1::BeginTransactionRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1::BeginTransactionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb
Overview
The request for Datastore.BeginTransaction.
Instance Attribute Summary collapse
-
#database_id ⇒ String
The ID of the database against which to make the request.
-
#request_options ⇒ Google::Apis::DatastoreV1::RequestOptions
Options for a request.
-
#transaction_options ⇒ Google::Apis::DatastoreV1::TransactionOptions
Options for beginning a new transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BeginTransactionRequest
constructor
A new instance of BeginTransactionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BeginTransactionRequest
Returns a new instance of BeginTransactionRequest.
291 292 293 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_id ⇒ String
The ID of the database against which to make the request. '(default)' is not
allowed; please use empty string '' to refer the default database.
Corresponds to the JSON property databaseId
277 278 279 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 277 def database_id @database_id end |
#request_options ⇒ Google::Apis::DatastoreV1::RequestOptions
Options for a request.
Corresponds to the JSON property requestOptions
282 283 284 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 282 def @request_options end |
#transaction_options ⇒ Google::Apis::DatastoreV1::TransactionOptions
Options for beginning a new transaction. Transactions can be created
explicitly with calls to Datastore.BeginTransaction or implicitly by setting
ReadOptions.new_transaction in read requests.
Corresponds to the JSON property transactionOptions
289 290 291 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 289 def @transaction_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
296 297 298 299 300 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 296 def update!(**args) @database_id = args[:database_id] if args.key?(:database_id) @request_options = args[:request_options] if args.key?(:request_options) @transaction_options = args[:transaction_options] if args.key?(:transaction_options) end |