Class: Google::Apis::DatastoreV1::ExplainOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

Explain options for the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainOptions

Returns a new instance of ExplainOptions.



642
643
644
# File 'lib/google/apis/datastore_v1/classes.rb', line 642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analyzeBoolean Also known as: analyze?

Optional. Whether to execute this query. When false (the default), the query will be planned, returning only metrics from the planning stages. When true, the query will be planned and executed, returning the full query results along with both planning and execution stage metrics. Corresponds to the JSON property analyze

Returns:

  • (Boolean)


639
640
641
# File 'lib/google/apis/datastore_v1/classes.rb', line 639

def analyze
  @analyze
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



647
648
649
# File 'lib/google/apis/datastore_v1/classes.rb', line 647

def update!(**args)
  @analyze = args[:analyze] if args.key?(:analyze)
end