Class: Google::Apis::DatastoreV1::GoogleDatastoreAdminV1PrepareStepDetails
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1::GoogleDatastoreAdminV1PrepareStepDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb
Overview
Details for the PREPARE step.
Instance Attribute Summary collapse
-
#concurrency_mode ⇒ String
The concurrency mode this database will use when it reaches the
REDIRECT_WRITESstep.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDatastoreAdminV1PrepareStepDetails
constructor
A new instance of GoogleDatastoreAdminV1PrepareStepDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDatastoreAdminV1PrepareStepDetails
Returns a new instance of GoogleDatastoreAdminV1PrepareStepDetails.
1267 1268 1269 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#concurrency_mode ⇒ String
The concurrency mode this database will use when it reaches the
REDIRECT_WRITES step.
Corresponds to the JSON property concurrencyMode
1265 1266 1267 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1265 def concurrency_mode @concurrency_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1272 1273 1274 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1272 def update!(**args) @concurrency_mode = args[:concurrency_mode] if args.key?(:concurrency_mode) end |