Class: Google::Apis::DatastoreV1::GqlQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GqlQuery

Returns a new instance of GqlQuery.



1667
1668
1669
# File 'lib/google/apis/datastore_v1/classes.rb', line 1667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_literalsBoolean Also known as: allow_literals?

When false, the query string must not contain any literals and instead must bind all values. For example, SELECT * FROM Kind WHERE a = 'string literal' is not allowed, while SELECT * FROM Kind WHERE a = @value is. Corresponds to the JSON property allowLiterals

Returns:

  • (Boolean)


1643
1644
1645
# File 'lib/google/apis/datastore_v1/classes.rb', line 1643

def allow_literals
  @allow_literals
end

#named_bindingsHash<String,Google::Apis::DatastoreV1::GqlQueryParameter>

For each non-reserved named binding site in the query string, there must be a named parameter with that name, but not necessarily the inverse. Key must match regex A-Za-z_$*, must not match regex __.*__, and must not be "". Corresponds to the JSON property namedBindings



1651
1652
1653
# File 'lib/google/apis/datastore_v1/classes.rb', line 1651

def named_bindings
  @named_bindings
end

#positional_bindingsArray<Google::Apis::DatastoreV1::GqlQueryParameter>

Numbered binding site @1 references the first numbered parameter, effectively using 1-based indexing, rather than the usual 0. For each binding site numbered i in query_string, there must be an i-th numbered parameter. The inverse must also be true. Corresponds to the JSON property positionalBindings



1659
1660
1661
# File 'lib/google/apis/datastore_v1/classes.rb', line 1659

def positional_bindings
  @positional_bindings
end

#query_stringString

A string of the format described here. Corresponds to the JSON property queryString

Returns:

  • (String)


1665
1666
1667
# File 'lib/google/apis/datastore_v1/classes.rb', line 1665

def query_string
  @query_string
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1672
1673
1674
1675
1676
1677
# File 'lib/google/apis/datastore_v1/classes.rb', line 1672

def update!(**args)
  @allow_literals = args[:allow_literals] if args.key?(:allow_literals)
  @named_bindings = args[:named_bindings] if args.key?(:named_bindings)
  @positional_bindings = args[:positional_bindings] if args.key?(:positional_bindings)
  @query_string = args[:query_string] if args.key?(:query_string)
end