Class: Google::Apis::DatastoreV1::LookupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

The request for Datastore.Lookup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LookupRequest

Returns a new instance of LookupRequest.



1827
1828
1829
# File 'lib/google/apis/datastore_v1/classes.rb', line 1827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

The ID of the database against which to make the request. '(default)' is not allowed; please use empty string '' to refer the default database. Corresponds to the JSON property databaseId

Returns:

  • (String)


1809
1810
1811
# File 'lib/google/apis/datastore_v1/classes.rb', line 1809

def database_id
  @database_id
end

#keysArray<Google::Apis::DatastoreV1::Key>

Required. Keys of entities to look up. Corresponds to the JSON property keys

Returns:



1814
1815
1816
# File 'lib/google/apis/datastore_v1/classes.rb', line 1814

def keys
  @keys
end

#property_maskGoogle::Apis::DatastoreV1::PropertyMask

The set of arbitrarily nested property paths used to restrict an operation to only a subset of properties in an entity. Corresponds to the JSON property propertyMask



1820
1821
1822
# File 'lib/google/apis/datastore_v1/classes.rb', line 1820

def property_mask
  @property_mask
end

#read_optionsGoogle::Apis::DatastoreV1::ReadOptions

The options shared by read requests. Corresponds to the JSON property readOptions



1825
1826
1827
# File 'lib/google/apis/datastore_v1/classes.rb', line 1825

def read_options
  @read_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1832
1833
1834
1835
1836
1837
# File 'lib/google/apis/datastore_v1/classes.rb', line 1832

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @keys = args[:keys] if args.key?(:keys)
  @property_mask = args[:property_mask] if args.key?(:property_mask)
  @read_options = args[:read_options] if args.key?(:read_options)
end