Class: Google::Apis::DatastoreV1::PropertyTransform

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

A transformation of an entity property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PropertyTransform

Returns a new instance of PropertyTransform.



2319
2320
2321
# File 'lib/google/apis/datastore_v1/classes.rb', line 2319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#append_missing_elementsGoogle::Apis::DatastoreV1::ArrayValue

An array value. Corresponds to the JSON property appendMissingElements



2280
2281
2282
# File 'lib/google/apis/datastore_v1/classes.rb', line 2280

def append_missing_elements
  @append_missing_elements
end

#incrementGoogle::Apis::DatastoreV1::Value

A message that can hold any of the supported value types and associated metadata. Corresponds to the JSON property increment



2286
2287
2288
# File 'lib/google/apis/datastore_v1/classes.rb', line 2286

def increment
  @increment
end

#maximumGoogle::Apis::DatastoreV1::Value

A message that can hold any of the supported value types and associated metadata. Corresponds to the JSON property maximum



2292
2293
2294
# File 'lib/google/apis/datastore_v1/classes.rb', line 2292

def maximum
  @maximum
end

#minimumGoogle::Apis::DatastoreV1::Value

A message that can hold any of the supported value types and associated metadata. Corresponds to the JSON property minimum



2298
2299
2300
# File 'lib/google/apis/datastore_v1/classes.rb', line 2298

def minimum
  @minimum
end

#propertyString

Optional. The name of the property. Property paths (a list of property names separated by dots (.)) may be used to refer to properties inside entity values. For example foo.bar means the property bar inside the entity property foo. If a property name contains a dot . or a backlslash \, then that name must be escaped. Corresponds to the JSON property property

Returns:

  • (String)


2307
2308
2309
# File 'lib/google/apis/datastore_v1/classes.rb', line 2307

def property
  @property
end

#remove_all_from_arrayGoogle::Apis::DatastoreV1::ArrayValue

An array value. Corresponds to the JSON property removeAllFromArray



2312
2313
2314
# File 'lib/google/apis/datastore_v1/classes.rb', line 2312

def remove_all_from_array
  @remove_all_from_array
end

#set_to_server_valueString

Sets the property to the given server value. Corresponds to the JSON property setToServerValue

Returns:

  • (String)


2317
2318
2319
# File 'lib/google/apis/datastore_v1/classes.rb', line 2317

def set_to_server_value
  @set_to_server_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2324
2325
2326
2327
2328
2329
2330
2331
2332
# File 'lib/google/apis/datastore_v1/classes.rb', line 2324

def update!(**args)
  @append_missing_elements = args[:append_missing_elements] if args.key?(:append_missing_elements)
  @increment = args[:increment] if args.key?(:increment)
  @maximum = args[:maximum] if args.key?(:maximum)
  @minimum = args[:minimum] if args.key?(:minimum)
  @property = args[:property] if args.key?(:property)
  @remove_all_from_array = args[:remove_all_from_array] if args.key?(:remove_all_from_array)
  @set_to_server_value = args[:set_to_server_value] if args.key?(:set_to_server_value)
end