Class: Google::Apis::DatastoreV1::QueryResultBatch
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1::QueryResultBatch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb
Overview
A batch of results produced by a query.
Instance Attribute Summary collapse
-
#end_cursor ⇒ String
A cursor that points to the position after the last result in the batch.
-
#entity_result_type ⇒ String
The result type for every entity in
entity_results. -
#entity_results ⇒ Array<Google::Apis::DatastoreV1::EntityResult>
The results for this batch.
-
#more_results ⇒ String
The state of the query after the current batch.
-
#read_time ⇒ String
Read timestamp this batch was returned from.
-
#skipped_cursor ⇒ String
A cursor that points to the position after the last skipped result.
-
#skipped_results ⇒ Fixnum
The number of results skipped, typically because of an offset.
-
#snapshot_version ⇒ Fixnum
The version number of the snapshot this batch was returned from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryResultBatch
constructor
A new instance of QueryResultBatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryResultBatch
Returns a new instance of QueryResultBatch.
2485 2486 2487 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_cursor ⇒ String
A cursor that points to the position after the last result in the batch.
Corresponds to the JSON property endCursor
NOTE: Values are automatically base64 encoded/decoded in the client library.
2434 2435 2436 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2434 def end_cursor @end_cursor end |
#entity_result_type ⇒ String
The result type for every entity in entity_results.
Corresponds to the JSON property entityResultType
2439 2440 2441 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2439 def entity_result_type @entity_result_type end |
#entity_results ⇒ Array<Google::Apis::DatastoreV1::EntityResult>
The results for this batch.
Corresponds to the JSON property entityResults
2444 2445 2446 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2444 def entity_results @entity_results end |
#more_results ⇒ String
The state of the query after the current batch.
Corresponds to the JSON property moreResults
2449 2450 2451 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2449 def more_results @more_results end |
#read_time ⇒ String
Read timestamp this batch was returned from. This applies to the range of
results from the query's start_cursor (or the beginning of the query if no
cursor was given) to this batch's end_cursor (not the query's end_cursor).
In a single transaction, subsequent query result batches for the same query
can have a greater timestamp. Each batch's read timestamp is valid for all
preceding batches. This value will not be set for eventually consistent
queries in Cloud Datastore.
Corresponds to the JSON property readTime
2460 2461 2462 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2460 def read_time @read_time end |
#skipped_cursor ⇒ String
A cursor that points to the position after the last skipped result. Will be
set when skipped_results != 0.
Corresponds to the JSON property skippedCursor
NOTE: Values are automatically base64 encoded/decoded in the client library.
2467 2468 2469 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2467 def skipped_cursor @skipped_cursor end |
#skipped_results ⇒ Fixnum
The number of results skipped, typically because of an offset.
Corresponds to the JSON property skippedResults
2472 2473 2474 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2472 def skipped_results @skipped_results end |
#snapshot_version ⇒ Fixnum
The version number of the snapshot this batch was returned from. This applies
to the range of results from the query's start_cursor (or the beginning of
the query if no cursor was given) to this batch's end_cursor (not the query'
s end_cursor). In a single transaction, subsequent query result batches for
the same query can have a greater snapshot version number. Each batch's
snapshot version is valid for all preceding batches. The value will be zero
for eventually consistent queries.
Corresponds to the JSON property snapshotVersion
2483 2484 2485 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2483 def snapshot_version @snapshot_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2490 def update!(**args) @end_cursor = args[:end_cursor] if args.key?(:end_cursor) @entity_result_type = args[:entity_result_type] if args.key?(:entity_result_type) @entity_results = args[:entity_results] if args.key?(:entity_results) @more_results = args[:more_results] if args.key?(:more_results) @read_time = args[:read_time] if args.key?(:read_time) @skipped_cursor = args[:skipped_cursor] if args.key?(:skipped_cursor) @skipped_results = args[:skipped_results] if args.key?(:skipped_results) @snapshot_version = args[:snapshot_version] if args.key?(:snapshot_version) end |