Class: Google::Apis::DatastoreV1::ReadOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

The options shared by read requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReadOptions

Returns a new instance of ReadOptions.



2554
2555
2556
# File 'lib/google/apis/datastore_v1/classes.rb', line 2554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_transactionGoogle::Apis::DatastoreV1::TransactionOptions

Options for beginning a new transaction. Transactions can be created explicitly with calls to Datastore.BeginTransaction or implicitly by setting ReadOptions.new_transaction in read requests. Corresponds to the JSON property newTransaction



2532
2533
2534
# File 'lib/google/apis/datastore_v1/classes.rb', line 2532

def new_transaction
  @new_transaction
end

#read_consistencyString

The non-transactional read consistency to use. Corresponds to the JSON property readConsistency

Returns:

  • (String)


2537
2538
2539
# File 'lib/google/apis/datastore_v1/classes.rb', line 2537

def read_consistency
  @read_consistency
end

#read_timeString

Reads entities as they were at the given time. This value is only supported for Cloud Firestore in Datastore mode. This must be a microsecond precision timestamp within the past one hour, or if Point-in-Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days. Corresponds to the JSON property readTime

Returns:

  • (String)


2545
2546
2547
# File 'lib/google/apis/datastore_v1/classes.rb', line 2545

def read_time
  @read_time
end

#transactionString

The identifier of the transaction in which to read. A transaction identifier is returned by a call to Datastore.BeginTransaction. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2552
2553
2554
# File 'lib/google/apis/datastore_v1/classes.rb', line 2552

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2559
2560
2561
2562
2563
2564
# File 'lib/google/apis/datastore_v1/classes.rb', line 2559

def update!(**args)
  @new_transaction = args[:new_transaction] if args.key?(:new_transaction)
  @read_consistency = args[:read_consistency] if args.key?(:read_consistency)
  @read_time = args[:read_time] if args.key?(:read_time)
  @transaction = args[:transaction] if args.key?(:transaction)
end