Class: Google::Apis::DatastoreV1::ReserveIdsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

The request for Datastore.ReserveIds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReserveIdsRequest

Returns a new instance of ReserveIdsRequest.



2629
2630
2631
# File 'lib/google/apis/datastore_v1/classes.rb', line 2629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

The ID of the database against which to make the request. '(default)' is not allowed; please use empty string '' to refer the default database. Corresponds to the JSON property databaseId

Returns:

  • (String)


2616
2617
2618
# File 'lib/google/apis/datastore_v1/classes.rb', line 2616

def database_id
  @database_id
end

#keysArray<Google::Apis::DatastoreV1::Key>

Required. A list of keys with complete key paths whose numeric IDs should not be auto-allocated. Corresponds to the JSON property keys

Returns:



2622
2623
2624
# File 'lib/google/apis/datastore_v1/classes.rb', line 2622

def keys
  @keys
end

#request_optionsGoogle::Apis::DatastoreV1::RequestOptions

Options for a request. Corresponds to the JSON property requestOptions



2627
2628
2629
# File 'lib/google/apis/datastore_v1/classes.rb', line 2627

def request_options
  @request_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2634
2635
2636
2637
2638
# File 'lib/google/apis/datastore_v1/classes.rb', line 2634

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @keys = args[:keys] if args.key?(:keys)
  @request_options = args[:request_options] if args.key?(:request_options)
end