Class: Google::Apis::DatastoreV1::RollbackRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

The request for Datastore.Rollback.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackRequest

Returns a new instance of RollbackRequest.



2676
2677
2678
# File 'lib/google/apis/datastore_v1/classes.rb', line 2676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

The ID of the database against which to make the request. '(default)' is not allowed; please use empty string '' to refer the default database. Corresponds to the JSON property databaseId

Returns:

  • (String)


2662
2663
2664
# File 'lib/google/apis/datastore_v1/classes.rb', line 2662

def database_id
  @database_id
end

#request_optionsGoogle::Apis::DatastoreV1::RequestOptions

Options for a request. Corresponds to the JSON property requestOptions



2667
2668
2669
# File 'lib/google/apis/datastore_v1/classes.rb', line 2667

def request_options
  @request_options
end

#transactionString

Required. The transaction identifier, returned by a call to Datastore. BeginTransaction. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2674
2675
2676
# File 'lib/google/apis/datastore_v1/classes.rb', line 2674

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2681
2682
2683
2684
2685
# File 'lib/google/apis/datastore_v1/classes.rb', line 2681

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @request_options = args[:request_options] if args.key?(:request_options)
  @transaction = args[:transaction] if args.key?(:transaction)
end