Class: Google::Apis::DatastoreV1::RunAggregationQueryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1::RunAggregationQueryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb
Overview
The request for Datastore.RunAggregationQuery.
Instance Attribute Summary collapse
-
#aggregation_query ⇒ Google::Apis::DatastoreV1::AggregationQuery
Datastore query for running an aggregation over a Query.
-
#database_id ⇒ String
The ID of the database against which to make the request.
-
#explain_options ⇒ Google::Apis::DatastoreV1::ExplainOptions
Explain options for the query.
-
#gql_query ⇒ Google::Apis::DatastoreV1::GqlQuery
A GQL query.
-
#partition_id ⇒ Google::Apis::DatastoreV1::PartitionId
A partition ID identifies a grouping of entities.
-
#read_options ⇒ Google::Apis::DatastoreV1::ReadOptions
The options shared by read requests.
-
#request_options ⇒ Google::Apis::DatastoreV1::RequestOptions
Options for a request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunAggregationQueryRequest
constructor
A new instance of RunAggregationQueryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunAggregationQueryRequest
Returns a new instance of RunAggregationQueryRequest.
2750 2751 2752 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_query ⇒ Google::Apis::DatastoreV1::AggregationQuery
Datastore query for running an aggregation over a Query.
Corresponds to the JSON property aggregationQuery
2708 2709 2710 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2708 def aggregation_query @aggregation_query end |
#database_id ⇒ String
The ID of the database against which to make the request. '(default)' is not
allowed; please use empty string '' to refer the default database.
Corresponds to the JSON property databaseId
2714 2715 2716 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2714 def database_id @database_id end |
#explain_options ⇒ Google::Apis::DatastoreV1::ExplainOptions
Explain options for the query.
Corresponds to the JSON property explainOptions
2719 2720 2721 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2719 def @explain_options end |
#gql_query ⇒ Google::Apis::DatastoreV1::GqlQuery
A GQL query.
Corresponds to the JSON property gqlQuery
2724 2725 2726 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2724 def gql_query @gql_query end |
#partition_id ⇒ Google::Apis::DatastoreV1::PartitionId
A partition ID identifies a grouping of entities. The grouping is always by project and namespace, however the namespace ID may be empty. A partition ID contains several dimensions: project ID and namespace ID. Partition dimensions:
- May be
"". - Must be valid UTF-8 bytes. - Must have values that match regex[A-Za-z\d\.\-_]1,100`If the value of any dimension matches regex. *, the partition is reserved/read-only. A reserved/read-only partition ID is forbidden in certain documented contexts. Foreign partition IDs (in which the project ID does not match the context project ID ) are discouraged. Reads and writes of foreign partition IDs may fail if the project is not in an active state. Corresponds to the JSON propertypartitionId`
2738 2739 2740 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2738 def partition_id @partition_id end |
#read_options ⇒ Google::Apis::DatastoreV1::ReadOptions
The options shared by read requests.
Corresponds to the JSON property readOptions
2743 2744 2745 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2743 def @read_options end |
#request_options ⇒ Google::Apis::DatastoreV1::RequestOptions
Options for a request.
Corresponds to the JSON property requestOptions
2748 2749 2750 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2748 def @request_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2755 2756 2757 2758 2759 2760 2761 2762 2763 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2755 def update!(**args) @aggregation_query = args[:aggregation_query] if args.key?(:aggregation_query) @database_id = args[:database_id] if args.key?(:database_id) @explain_options = args[:explain_options] if args.key?(:explain_options) @gql_query = args[:gql_query] if args.key?(:gql_query) @partition_id = args[:partition_id] if args.key?(:partition_id) @read_options = args[:read_options] if args.key?(:read_options) @request_options = args[:request_options] if args.key?(:request_options) end |