Class: Google::Apis::DatastoreV1::RunQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

The request for Datastore.RunQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunQueryRequest

Returns a new instance of RunQueryRequest.



2863
2864
2865
# File 'lib/google/apis/datastore_v1/classes.rb', line 2863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

The ID of the database against which to make the request. '(default)' is not allowed; please use empty string '' to refer the default database. Corresponds to the JSON property databaseId

Returns:

  • (String)


2814
2815
2816
# File 'lib/google/apis/datastore_v1/classes.rb', line 2814

def database_id
  @database_id
end

#explain_optionsGoogle::Apis::DatastoreV1::ExplainOptions

Explain options for the query. Corresponds to the JSON property explainOptions



2819
2820
2821
# File 'lib/google/apis/datastore_v1/classes.rb', line 2819

def explain_options
  @explain_options
end

#gql_queryGoogle::Apis::DatastoreV1::GqlQuery

A GQL query. Corresponds to the JSON property gqlQuery



2824
2825
2826
# File 'lib/google/apis/datastore_v1/classes.rb', line 2824

def gql_query
  @gql_query
end

#partition_idGoogle::Apis::DatastoreV1::PartitionId

A partition ID identifies a grouping of entities. The grouping is always by project and namespace, however the namespace ID may be empty. A partition ID contains several dimensions: project ID and namespace ID. Partition dimensions:

  • May be "". - Must be valid UTF-8 bytes. - Must have values that match regex [A-Za-z\d\.\-_]1,100`If the value of any dimension matches regex. *, the partition is reserved/read-only. A reserved/read-only partition ID is forbidden in certain documented contexts. Foreign partition IDs (in which the project ID does not match the context project ID ) are discouraged. Reads and writes of foreign partition IDs may fail if the project is not in an active state. Corresponds to the JSON propertypartitionId`


2838
2839
2840
# File 'lib/google/apis/datastore_v1/classes.rb', line 2838

def partition_id
  @partition_id
end

#property_maskGoogle::Apis::DatastoreV1::PropertyMask

The set of arbitrarily nested property paths used to restrict an operation to only a subset of properties in an entity. Corresponds to the JSON property propertyMask



2844
2845
2846
# File 'lib/google/apis/datastore_v1/classes.rb', line 2844

def property_mask
  @property_mask
end

#queryGoogle::Apis::DatastoreV1::Query

A query for entities. The query stages are executed in the following order: 1. kind 2. filter 3. projection 4. order + start_cursor + end_cursor 5. offset 6. limit 7. find_nearest Corresponds to the JSON property query



2851
2852
2853
# File 'lib/google/apis/datastore_v1/classes.rb', line 2851

def query
  @query
end

#read_optionsGoogle::Apis::DatastoreV1::ReadOptions

The options shared by read requests. Corresponds to the JSON property readOptions



2856
2857
2858
# File 'lib/google/apis/datastore_v1/classes.rb', line 2856

def read_options
  @read_options
end

#request_optionsGoogle::Apis::DatastoreV1::RequestOptions

Options for a request. Corresponds to the JSON property requestOptions



2861
2862
2863
# File 'lib/google/apis/datastore_v1/classes.rb', line 2861

def request_options
  @request_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
# File 'lib/google/apis/datastore_v1/classes.rb', line 2868

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @explain_options = args[:explain_options] if args.key?(:explain_options)
  @gql_query = args[:gql_query] if args.key?(:gql_query)
  @partition_id = args[:partition_id] if args.key?(:partition_id)
  @property_mask = args[:property_mask] if args.key?(:property_mask)
  @query = args[:query] if args.key?(:query)
  @read_options = args[:read_options] if args.key?(:read_options)
  @request_options = args[:request_options] if args.key?(:request_options)
end