Class: Google::Apis::DatastoreV1::GoogleDatastoreAdminV1ExportEntitiesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1::GoogleDatastoreAdminV1ExportEntitiesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb
Overview
The request for google.datastore.admin.v1.DatastoreAdmin.ExportEntities.
Instance Attribute Summary collapse
-
#entity_filter ⇒ Google::Apis::DatastoreV1::GoogleDatastoreAdminV1EntityFilter
Identifies a subset of entities in a project.
-
#labels ⇒ Hash<String,String>
Client-assigned labels.
-
#output_url_prefix ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDatastoreAdminV1ExportEntitiesRequest
constructor
A new instance of GoogleDatastoreAdminV1ExportEntitiesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDatastoreAdminV1ExportEntitiesRequest
Returns a new instance of GoogleDatastoreAdminV1ExportEntitiesRequest.
939 940 941 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 939 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity_filter ⇒ Google::Apis::DatastoreV1::GoogleDatastoreAdminV1EntityFilter
Identifies a subset of entities in a project. This is specified as
combinations of kinds and namespaces (either or both of which may be all, as
described in the following examples). Example usage: Entire project: kinds=[],
namespace_ids=[] Kinds Foo and Bar in all namespaces: kinds=['Foo', 'Bar'],
namespace_ids=[] Kinds Foo and Bar only in the default namespace: kinds=['Foo',
'Bar'], namespace_ids=[''] Kinds Foo and Bar in both the default and Baz
namespaces: kinds=['Foo', 'Bar'], namespace_ids=['', 'Baz'] The entire Baz
namespace: kinds=[], namespace_ids=['Baz']
Corresponds to the JSON property entityFilter
915 916 917 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 915 def entity_filter @entity_filter end |
#labels ⇒ Hash<String,String>
Client-assigned labels.
Corresponds to the JSON property labels
920 921 922 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 920 def labels @labels end |
#output_url_prefix ⇒ String
Required. Location for the export metadata and data files. The full resource
URL of the external storage location. Currently, only Google Cloud Storage is
supported. So output_url_prefix should be of the form: gs://BUCKET_NAME[/
NAMESPACE_PATH], where BUCKET_NAME is the name of the Cloud Storage bucket
and NAMESPACE_PATH is an optional Cloud Storage namespace path (this is not
a Cloud Datastore namespace). For more information about Cloud Storage
namespace paths, see Object name considerations. The resulting files will be nested
deeper than the specified URL prefix. The final output URL will be provided in
the google.datastore.admin.v1.ExportEntitiesResponse.output_url field. That
value should be used for subsequent ImportEntities operations. By nesting the
data files deeper, the same Cloud Storage bucket can be used in multiple
ExportEntities operations without conflict.
Corresponds to the JSON property outputUrlPrefix
937 938 939 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 937 def output_url_prefix @output_url_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
944 945 946 947 948 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 944 def update!(**args) @entity_filter = args[:entity_filter] if args.key?(:entity_filter) @labels = args[:labels] if args.key?(:labels) @output_url_prefix = args[:output_url_prefix] if args.key?(:output_url_prefix) end |