Class: Google::Apis::DatastoreV1::LookupResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1::LookupResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb
Overview
The response for Datastore.Lookup.
Instance Attribute Summary collapse
-
#deferred ⇒ Array<Google::Apis::DatastoreV1::Key>
A list of keys that were not looked up due to resource constraints.
-
#found ⇒ Array<Google::Apis::DatastoreV1::EntityResult>
Entities found as
ResultType.FULLentities. -
#missing ⇒ Array<Google::Apis::DatastoreV1::EntityResult>
Entities not found as
ResultType.KEY_ONLYentities. -
#read_time ⇒ String
The time at which these entities were read or found missing.
-
#transaction ⇒ String
The identifier of the transaction that was started as part of this Lookup request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LookupResponse
constructor
A new instance of LookupResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LookupResponse
Returns a new instance of LookupResponse.
1877 1878 1879 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deferred ⇒ Array<Google::Apis::DatastoreV1::Key>
A list of keys that were not looked up due to resource constraints. The order
of results in this field is undefined and has no relation to the order of the
keys in the input.
Corresponds to the JSON property deferred
1849 1850 1851 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1849 def deferred @deferred end |
#found ⇒ Array<Google::Apis::DatastoreV1::EntityResult>
Entities found as ResultType.FULL entities. The order of results in this
field is undefined and has no relation to the order of the keys in the input.
Corresponds to the JSON property found
1855 1856 1857 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1855 def found @found end |
#missing ⇒ Array<Google::Apis::DatastoreV1::EntityResult>
Entities not found as ResultType.KEY_ONLY entities. The order of results in
this field is undefined and has no relation to the order of the keys in the
input.
Corresponds to the JSON property missing
1862 1863 1864 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1862 def missing @missing end |
#read_time ⇒ String
The time at which these entities were read or found missing.
Corresponds to the JSON property readTime
1867 1868 1869 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1867 def read_time @read_time end |
#transaction ⇒ String
The identifier of the transaction that was started as part of this Lookup
request. Set only when ReadOptions.new_transaction was set in LookupRequest.
read_options.
Corresponds to the JSON property transaction
NOTE: Values are automatically base64 encoded/decoded in the client library.
1875 1876 1877 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1875 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1882 1883 1884 1885 1886 1887 1888 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 1882 def update!(**args) @deferred = args[:deferred] if args.key?(:deferred) @found = args[:found] if args.key?(:found) @missing = args[:missing] if args.key?(:missing) @read_time = args[:read_time] if args.key?(:read_time) @transaction = args[:transaction] if args.key?(:transaction) end |