Class: Google::Apis::DatastoreV1::QueryResultBatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

A batch of results produced by a query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryResultBatch

Returns a new instance of QueryResultBatch.



2461
2462
2463
# File 'lib/google/apis/datastore_v1/classes.rb', line 2461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_cursorString

A cursor that points to the position after the last result in the batch. Corresponds to the JSON property endCursor NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2410
2411
2412
# File 'lib/google/apis/datastore_v1/classes.rb', line 2410

def end_cursor
  @end_cursor
end

#entity_result_typeString

The result type for every entity in entity_results. Corresponds to the JSON property entityResultType

Returns:

  • (String)


2415
2416
2417
# File 'lib/google/apis/datastore_v1/classes.rb', line 2415

def entity_result_type
  @entity_result_type
end

#entity_resultsArray<Google::Apis::DatastoreV1::EntityResult>

The results for this batch. Corresponds to the JSON property entityResults



2420
2421
2422
# File 'lib/google/apis/datastore_v1/classes.rb', line 2420

def entity_results
  @entity_results
end

#more_resultsString

The state of the query after the current batch. Corresponds to the JSON property moreResults

Returns:

  • (String)


2425
2426
2427
# File 'lib/google/apis/datastore_v1/classes.rb', line 2425

def more_results
  @more_results
end

#read_timeString

Read timestamp this batch was returned from. This applies to the range of results from the query's start_cursor (or the beginning of the query if no cursor was given) to this batch's end_cursor (not the query's end_cursor). In a single transaction, subsequent query result batches for the same query can have a greater timestamp. Each batch's read timestamp is valid for all preceding batches. This value will not be set for eventually consistent queries in Cloud Datastore. Corresponds to the JSON property readTime

Returns:

  • (String)


2436
2437
2438
# File 'lib/google/apis/datastore_v1/classes.rb', line 2436

def read_time
  @read_time
end

#skipped_cursorString

A cursor that points to the position after the last skipped result. Will be set when skipped_results != 0. Corresponds to the JSON property skippedCursor NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2443
2444
2445
# File 'lib/google/apis/datastore_v1/classes.rb', line 2443

def skipped_cursor
  @skipped_cursor
end

#skipped_resultsFixnum

The number of results skipped, typically because of an offset. Corresponds to the JSON property skippedResults

Returns:

  • (Fixnum)


2448
2449
2450
# File 'lib/google/apis/datastore_v1/classes.rb', line 2448

def skipped_results
  @skipped_results
end

#snapshot_versionFixnum

The version number of the snapshot this batch was returned from. This applies to the range of results from the query's start_cursor (or the beginning of the query if no cursor was given) to this batch's end_cursor (not the query' s end_cursor). In a single transaction, subsequent query result batches for the same query can have a greater snapshot version number. Each batch's snapshot version is valid for all preceding batches. The value will be zero for eventually consistent queries. Corresponds to the JSON property snapshotVersion

Returns:

  • (Fixnum)


2459
2460
2461
# File 'lib/google/apis/datastore_v1/classes.rb', line 2459

def snapshot_version
  @snapshot_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
# File 'lib/google/apis/datastore_v1/classes.rb', line 2466

def update!(**args)
  @end_cursor = args[:end_cursor] if args.key?(:end_cursor)
  @entity_result_type = args[:entity_result_type] if args.key?(:entity_result_type)
  @entity_results = args[:entity_results] if args.key?(:entity_results)
  @more_results = args[:more_results] if args.key?(:more_results)
  @read_time = args[:read_time] if args.key?(:read_time)
  @skipped_cursor = args[:skipped_cursor] if args.key?(:skipped_cursor)
  @skipped_results = args[:skipped_results] if args.key?(:skipped_results)
  @snapshot_version = args[:snapshot_version] if args.key?(:snapshot_version)
end