Class: Google::Apis::DatastoreV1::RunAggregationQueryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1::RunAggregationQueryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb
Overview
The request for Datastore.RunAggregationQuery.
Instance Attribute Summary collapse
-
#aggregation_query ⇒ Google::Apis::DatastoreV1::AggregationQuery
Datastore query for running an aggregation over a Query.
-
#database_id ⇒ String
The ID of the database against which to make the request.
-
#explain_options ⇒ Google::Apis::DatastoreV1::ExplainOptions
Explain options for the query.
-
#gql_query ⇒ Google::Apis::DatastoreV1::GqlQuery
A GQL query.
-
#partition_id ⇒ Google::Apis::DatastoreV1::PartitionId
A partition ID identifies a grouping of entities.
-
#read_options ⇒ Google::Apis::DatastoreV1::ReadOptions
The options shared by read requests.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunAggregationQueryRequest
constructor
A new instance of RunAggregationQueryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunAggregationQueryRequest
Returns a new instance of RunAggregationQueryRequest.
2688 2689 2690 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_query ⇒ Google::Apis::DatastoreV1::AggregationQuery
Datastore query for running an aggregation over a Query.
Corresponds to the JSON property aggregationQuery
2651 2652 2653 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2651 def aggregation_query @aggregation_query end |
#database_id ⇒ String
The ID of the database against which to make the request. '(default)' is not
allowed; please use empty string '' to refer the default database.
Corresponds to the JSON property databaseId
2657 2658 2659 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2657 def database_id @database_id end |
#explain_options ⇒ Google::Apis::DatastoreV1::ExplainOptions
Explain options for the query.
Corresponds to the JSON property explainOptions
2662 2663 2664 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2662 def @explain_options end |
#gql_query ⇒ Google::Apis::DatastoreV1::GqlQuery
A GQL query.
Corresponds to the JSON property gqlQuery
2667 2668 2669 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2667 def gql_query @gql_query end |
#partition_id ⇒ Google::Apis::DatastoreV1::PartitionId
A partition ID identifies a grouping of entities. The grouping is always by project and namespace, however the namespace ID may be empty. A partition ID contains several dimensions: project ID and namespace ID. Partition dimensions:
- May be
"". - Must be valid UTF-8 bytes. - Must have values that match regex[A-Za-z\d\.\-_]1,100`If the value of any dimension matches regex. *, the partition is reserved/read-only. A reserved/read-only partition ID is forbidden in certain documented contexts. Foreign partition IDs (in which the project ID does not match the context project ID ) are discouraged. Reads and writes of foreign partition IDs may fail if the project is not in an active state. Corresponds to the JSON propertypartitionId`
2681 2682 2683 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2681 def partition_id @partition_id end |
#read_options ⇒ Google::Apis::DatastoreV1::ReadOptions
The options shared by read requests.
Corresponds to the JSON property readOptions
2686 2687 2688 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2686 def @read_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2693 2694 2695 2696 2697 2698 2699 2700 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 2693 def update!(**args) @aggregation_query = args[:aggregation_query] if args.key?(:aggregation_query) @database_id = args[:database_id] if args.key?(:database_id) @explain_options = args[:explain_options] if args.key?(:explain_options) @gql_query = args[:gql_query] if args.key?(:gql_query) @partition_id = args[:partition_id] if args.key?(:partition_id) @read_options = args[:read_options] if args.key?(:read_options) end |