Class: Google::Apis::DatastoreV1::RunQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

The request for Datastore.RunQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunQueryRequest

Returns a new instance of RunQueryRequest.



2795
2796
2797
# File 'lib/google/apis/datastore_v1/classes.rb', line 2795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

The ID of the database against which to make the request. '(default)' is not allowed; please use empty string '' to refer the default database. Corresponds to the JSON property databaseId

Returns:

  • (String)


2751
2752
2753
# File 'lib/google/apis/datastore_v1/classes.rb', line 2751

def database_id
  @database_id
end

#explain_optionsGoogle::Apis::DatastoreV1::ExplainOptions

Explain options for the query. Corresponds to the JSON property explainOptions



2756
2757
2758
# File 'lib/google/apis/datastore_v1/classes.rb', line 2756

def explain_options
  @explain_options
end

#gql_queryGoogle::Apis::DatastoreV1::GqlQuery

A GQL query. Corresponds to the JSON property gqlQuery



2761
2762
2763
# File 'lib/google/apis/datastore_v1/classes.rb', line 2761

def gql_query
  @gql_query
end

#partition_idGoogle::Apis::DatastoreV1::PartitionId

A partition ID identifies a grouping of entities. The grouping is always by project and namespace, however the namespace ID may be empty. A partition ID contains several dimensions: project ID and namespace ID. Partition dimensions:

  • May be "". - Must be valid UTF-8 bytes. - Must have values that match regex [A-Za-z\d\.\-_]1,100`If the value of any dimension matches regex. *, the partition is reserved/read-only. A reserved/read-only partition ID is forbidden in certain documented contexts. Foreign partition IDs (in which the project ID does not match the context project ID ) are discouraged. Reads and writes of foreign partition IDs may fail if the project is not in an active state. Corresponds to the JSON propertypartitionId`


2775
2776
2777
# File 'lib/google/apis/datastore_v1/classes.rb', line 2775

def partition_id
  @partition_id
end

#property_maskGoogle::Apis::DatastoreV1::PropertyMask

The set of arbitrarily nested property paths used to restrict an operation to only a subset of properties in an entity. Corresponds to the JSON property propertyMask



2781
2782
2783
# File 'lib/google/apis/datastore_v1/classes.rb', line 2781

def property_mask
  @property_mask
end

#queryGoogle::Apis::DatastoreV1::Query

A query for entities. The query stages are executed in the following order: 1. kind 2. filter 3. projection 4. order + start_cursor + end_cursor 5. offset 6. limit 7. find_nearest Corresponds to the JSON property query



2788
2789
2790
# File 'lib/google/apis/datastore_v1/classes.rb', line 2788

def query
  @query
end

#read_optionsGoogle::Apis::DatastoreV1::ReadOptions

The options shared by read requests. Corresponds to the JSON property readOptions



2793
2794
2795
# File 'lib/google/apis/datastore_v1/classes.rb', line 2793

def read_options
  @read_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'lib/google/apis/datastore_v1/classes.rb', line 2800

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @explain_options = args[:explain_options] if args.key?(:explain_options)
  @gql_query = args[:gql_query] if args.key?(:gql_query)
  @partition_id = args[:partition_id] if args.key?(:partition_id)
  @property_mask = args[:property_mask] if args.key?(:property_mask)
  @query = args[:query] if args.key?(:query)
  @read_options = args[:read_options] if args.key?(:read_options)
end