Class: Google::Apis::DatastoreV1::Value
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1::Value
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb
Overview
A message that can hold any of the supported value types and associated metadata.
Instance Attribute Summary collapse
-
#array_value ⇒ Google::Apis::DatastoreV1::ArrayValue
An array value.
-
#blob_value ⇒ String
A blob value.
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
A boolean value.
-
#double_value ⇒ Float
A double value.
-
#entity_value ⇒ Google::Apis::DatastoreV1::Entity
A Datastore data object.
-
#exclude_from_indexes ⇒ Boolean
(also: #exclude_from_indexes?)
If the value should be excluded from all indexes including those defined explicitly.
-
#geo_point_value ⇒ Google::Apis::DatastoreV1::LatLng
An object that represents a latitude/longitude pair.
-
#integer_value ⇒ Fixnum
An integer value.
-
#key_value ⇒ Google::Apis::DatastoreV1::Key
A unique identifier for an entity.
-
#meaning ⇒ Fixnum
The
meaningfield should only be populated for backwards compatibility. -
#null_value ⇒ String
A null value.
-
#string_value ⇒ String
A UTF-8 encoded string value.
-
#timestamp_value ⇒ String
A timestamp value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Value
constructor
A new instance of Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Value
Returns a new instance of Value.
3102 3103 3104 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#array_value ⇒ Google::Apis::DatastoreV1::ArrayValue
An array value.
Corresponds to the JSON property arrayValue
3027 3028 3029 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3027 def array_value @array_value end |
#blob_value ⇒ String
A blob value. May have at most 1,000,000 bytes. When exclude_from_indexes is
false, may have at most 1500 bytes. In JSON requests, must be base64-encoded.
Corresponds to the JSON property blobValue
NOTE: Values are automatically base64 encoded/decoded in the client library.
3034 3035 3036 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3034 def blob_value @blob_value end |
#boolean_value ⇒ Boolean Also known as: boolean_value?
A boolean value.
Corresponds to the JSON property booleanValue
3039 3040 3041 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3039 def boolean_value @boolean_value end |
#double_value ⇒ Float
A double value.
Corresponds to the JSON property doubleValue
3045 3046 3047 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3045 def double_value @double_value end |
#entity_value ⇒ Google::Apis::DatastoreV1::Entity
A Datastore data object. Must not exceed 1 MiB - 4 bytes.
Corresponds to the JSON property entityValue
3050 3051 3052 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3050 def entity_value @entity_value end |
#exclude_from_indexes ⇒ Boolean Also known as: exclude_from_indexes?
If the value should be excluded from all indexes including those defined
explicitly.
Corresponds to the JSON property excludeFromIndexes
3056 3057 3058 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3056 def exclude_from_indexes @exclude_from_indexes end |
#geo_point_value ⇒ Google::Apis::DatastoreV1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property geoPointValue
3065 3066 3067 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3065 def geo_point_value @geo_point_value end |
#integer_value ⇒ Fixnum
An integer value.
Corresponds to the JSON property integerValue
3070 3071 3072 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3070 def integer_value @integer_value end |
#key_value ⇒ Google::Apis::DatastoreV1::Key
A unique identifier for an entity. If a key's partition ID or any of its path
kinds or names are reserved/read-only, the key is reserved/read-only. A
reserved/read-only key is forbidden in certain documented contexts.
Corresponds to the JSON property keyValue
3077 3078 3079 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3077 def key_value @key_value end |
#meaning ⇒ Fixnum
The meaning field should only be populated for backwards compatibility.
Corresponds to the JSON property meaning
3082 3083 3084 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3082 def meaning @meaning end |
#null_value ⇒ String
A null value.
Corresponds to the JSON property nullValue
3087 3088 3089 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3087 def null_value @null_value end |
#string_value ⇒ String
A UTF-8 encoded string value. When exclude_from_indexes is false (it is
indexed) , may have at most 1500 bytes. Otherwise, may be set to at most 1,000,
000 bytes.
Corresponds to the JSON property stringValue
3094 3095 3096 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3094 def string_value @string_value end |
#timestamp_value ⇒ String
A timestamp value. When stored in the Datastore, precise only to microseconds;
any additional precision is rounded down.
Corresponds to the JSON property timestampValue
3100 3101 3102 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3100 def @timestamp_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 |
# File 'lib/google/apis/datastore_v1/classes.rb', line 3107 def update!(**args) @array_value = args[:array_value] if args.key?(:array_value) @blob_value = args[:blob_value] if args.key?(:blob_value) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @double_value = args[:double_value] if args.key?(:double_value) @entity_value = args[:entity_value] if args.key?(:entity_value) @exclude_from_indexes = args[:exclude_from_indexes] if args.key?(:exclude_from_indexes) @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value) @integer_value = args[:integer_value] if args.key?(:integer_value) @key_value = args[:key_value] if args.key?(:key_value) @meaning = args[:meaning] if args.key?(:meaning) @null_value = args[:null_value] if args.key?(:null_value) @string_value = args[:string_value] if args.key?(:string_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) end |