Class: Google::Apis::DatastoreV1::Value

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastore_v1/classes.rb,
lib/google/apis/datastore_v1/representations.rb,
lib/google/apis/datastore_v1/representations.rb

Overview

A message that can hold any of the supported value types and associated metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Value

Returns a new instance of Value.



3033
3034
3035
# File 'lib/google/apis/datastore_v1/classes.rb', line 3033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valueGoogle::Apis::DatastoreV1::ArrayValue

An array value. Corresponds to the JSON property arrayValue



2958
2959
2960
# File 'lib/google/apis/datastore_v1/classes.rb', line 2958

def array_value
  @array_value
end

#blob_valueString

A blob value. May have at most 1,000,000 bytes. When exclude_from_indexes is false, may have at most 1500 bytes. In JSON requests, must be base64-encoded. Corresponds to the JSON property blobValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2965
2966
2967
# File 'lib/google/apis/datastore_v1/classes.rb', line 2965

def blob_value
  @blob_value
end

#boolean_valueBoolean Also known as: boolean_value?

A boolean value. Corresponds to the JSON property booleanValue

Returns:

  • (Boolean)


2970
2971
2972
# File 'lib/google/apis/datastore_v1/classes.rb', line 2970

def boolean_value
  @boolean_value
end

#double_valueFloat

A double value. Corresponds to the JSON property doubleValue

Returns:

  • (Float)


2976
2977
2978
# File 'lib/google/apis/datastore_v1/classes.rb', line 2976

def double_value
  @double_value
end

#entity_valueGoogle::Apis::DatastoreV1::Entity

A Datastore data object. Must not exceed 1 MiB - 4 bytes. Corresponds to the JSON property entityValue



2981
2982
2983
# File 'lib/google/apis/datastore_v1/classes.rb', line 2981

def entity_value
  @entity_value
end

#exclude_from_indexesBoolean Also known as: exclude_from_indexes?

If the value should be excluded from all indexes including those defined explicitly. Corresponds to the JSON property excludeFromIndexes

Returns:

  • (Boolean)


2987
2988
2989
# File 'lib/google/apis/datastore_v1/classes.rb', line 2987

def exclude_from_indexes
  @exclude_from_indexes
end

#geo_point_valueGoogle::Apis::DatastoreV1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property geoPointValue



2996
2997
2998
# File 'lib/google/apis/datastore_v1/classes.rb', line 2996

def geo_point_value
  @geo_point_value
end

#integer_valueFixnum

An integer value. Corresponds to the JSON property integerValue

Returns:

  • (Fixnum)


3001
3002
3003
# File 'lib/google/apis/datastore_v1/classes.rb', line 3001

def integer_value
  @integer_value
end

#key_valueGoogle::Apis::DatastoreV1::Key

A unique identifier for an entity. If a key's partition ID or any of its path kinds or names are reserved/read-only, the key is reserved/read-only. A reserved/read-only key is forbidden in certain documented contexts. Corresponds to the JSON property keyValue



3008
3009
3010
# File 'lib/google/apis/datastore_v1/classes.rb', line 3008

def key_value
  @key_value
end

#meaningFixnum

The meaning field should only be populated for backwards compatibility. Corresponds to the JSON property meaning

Returns:

  • (Fixnum)


3013
3014
3015
# File 'lib/google/apis/datastore_v1/classes.rb', line 3013

def meaning
  @meaning
end

#null_valueString

A null value. Corresponds to the JSON property nullValue

Returns:

  • (String)


3018
3019
3020
# File 'lib/google/apis/datastore_v1/classes.rb', line 3018

def null_value
  @null_value
end

#string_valueString

A UTF-8 encoded string value. When exclude_from_indexes is false (it is indexed) , may have at most 1500 bytes. Otherwise, may be set to at most 1,000, 000 bytes. Corresponds to the JSON property stringValue

Returns:

  • (String)


3025
3026
3027
# File 'lib/google/apis/datastore_v1/classes.rb', line 3025

def string_value
  @string_value
end

#timestamp_valueString

A timestamp value. When stored in the Datastore, precise only to microseconds; any additional precision is rounded down. Corresponds to the JSON property timestampValue

Returns:

  • (String)


3031
3032
3033
# File 'lib/google/apis/datastore_v1/classes.rb', line 3031

def timestamp_value
  @timestamp_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3038
3039
3040
3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
# File 'lib/google/apis/datastore_v1/classes.rb', line 3038

def update!(**args)
  @array_value = args[:array_value] if args.key?(:array_value)
  @blob_value = args[:blob_value] if args.key?(:blob_value)
  @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
  @double_value = args[:double_value] if args.key?(:double_value)
  @entity_value = args[:entity_value] if args.key?(:entity_value)
  @exclude_from_indexes = args[:exclude_from_indexes] if args.key?(:exclude_from_indexes)
  @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value)
  @integer_value = args[:integer_value] if args.key?(:integer_value)
  @key_value = args[:key_value] if args.key?(:key_value)
  @meaning = args[:meaning] if args.key?(:meaning)
  @null_value = args[:null_value] if args.key?(:null_value)
  @string_value = args[:string_value] if args.key?(:string_value)
  @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value)
end